package com.example.autocamerademo;

import java.io.FileOutputStream;
import java.io.IOException;

import android.app.Activity;
import android.hardware.Camera;
import android.hardware.Camera.PictureCallback;
import android.hardware.Camera.ShutterCallback;
import android.os.Bundle;
import android.os.CountDownTimer;
import android.util.Log;
import android.view.Menu;
import android.widget.FrameLayout;

public class MainActivity extends Activity {
	
	public static final String TAG = "AutoCameraDemo";
	private static final String PHOTO_NAME = "myphoto";
	private Preview mPreview;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		
		/** You must declared surface(preview) before take picture **/
		mPreview = new Preview(this);
		((FrameLayout) findViewById(R.id.preview)).addView(mPreview);
		
		/** In order to avoid behavior(take photo) happened before preview complete,
		 * 	Use count down timer to block thread.
		 */
		
		new CountDownTimer(3000, 1000) {
			
			@Override
			public void onTick(long millisUntilFinished) {
				Log.w(TAG, "" + millisUntilFinished);			
			}
			
			@Override
			public void onFinish() {
				mPreview.camera.takePicture(mShutterCallback, mRawCallback, mJpegCallback);
			}
		}.start();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
	ShutterCallback mShutterCallback = new ShutterCallback() {
		public void onShutter() {
			Log.w(TAG, "onShutter");
		}
	};
		
	@Override
	protected void onDestroy() {
		super.onDestroy();
	}

	PictureCallback mRawCallback = new PictureCallback() {
		public void onPictureTaken(byte[] data, Camera camera) {
			Log.w(TAG, "onPictureTaken - raw");
		}
	};
	
	PictureCallback mJpegCallback = new PictureCallback() {

		@Override
		public void onPictureTaken(byte[] data, Camera camera) {
			/** Standard method about writing data to media, if you have performance concerns.. **/
			// Uri uriTarget = getContentResolver().insert(Media.EXTERNAL_CONTENT_URI, new ContentValues());
			// OutputStream outStream = null;
			
			FileOutputStream outStream = null;
			try {
				outStream = new FileOutputStream(String.format("/storage/sdcard0/Download/%s.jpg", PHOTO_NAME));
				// outStream = getContentResolver().openOutputStream(uriTarget);
				outStream.write(data);
				outStream.close();
				
				Log.w(TAG, "Take a shot!");
			} catch (IOException e1) {
				e1.printStackTrace();
			} 
		}
	};
	
}
